@@ -6,9 +6,7 @@ from defer.sugar._parse import _ParseDefer
 
 def uninstall():
     if isinstance((trace := sys.gettrace()), _ParseDefer):
-        sys.settrace(
-            trace.tracefn if trace.tracefn is not _ParseDefer.IDENTITY else None
-        )
+        sys.settrace(trace.tracefn)
 
 
 defer = Defer()
